Index: Ringtoets/HydraRing/test/Ringtoets.HydraRing.Calculation.Test/Data/Input/Overtopping/OvertoppingCalculationInputTest.cs
===================================================================
diff -u -rdec46d5efaad5332ffb2a96e67ec11209ddc5515 -rf4c5904adf196826278061be33fe3adbc9ad4bc8
--- Ringtoets/HydraRing/test/Ringtoets.HydraRing.Calculation.Test/Data/Input/Overtopping/OvertoppingCalculationInputTest.cs (.../OvertoppingCalculationInputTest.cs) (revision dec46d5efaad5332ffb2a96e67ec11209ddc5515)
+++ Ringtoets/HydraRing/test/Ringtoets.HydraRing.Calculation.Test/Data/Input/Overtopping/OvertoppingCalculationInputTest.cs (.../OvertoppingCalculationInputTest.cs) (revision f4c5904adf196826278061be33fe3adbc9ad4bc8)
@@ -34,10 +34,8 @@
public void Constructor_Always_ExpectedValues()
{
// Setup
- const int expectedCalculationTypeId = 1;
- const int expectedVariableId = 1;
int hydraulicBoundaryLocationId = 1000;
- HydraRingSection expectedHydraRingSection = new HydraRingSection(expectedVariableId, "1000", double.NaN, double.NaN);
+ HydraRingSection expectedHydraRingSection = new HydraRingSection(1, "1000", double.NaN, double.NaN);
const double dikeHeight = 11.11;
const double modelFactorCriticalOvertopping = 1;
@@ -71,6 +69,8 @@
expectedRingProfilePoints, expectedRingForelandPoints, expectedRingBreakWater);
// Assert
+ const int expectedCalculationTypeId = 1;
+ const int expectedVariableId = 1;
Assert.AreEqual(expectedCalculationTypeId, overtoppingCalculationInput.CalculationTypeId);
Assert.AreEqual(hydraulicBoundaryLocationId, overtoppingCalculationInput.HydraulicBoundaryLocationId);
Assert.AreEqual(HydraRingFailureMechanismType.DikesOvertopping, overtoppingCalculationInput.FailureMechanismType);
Index: Ringtoets/HydraRing/test/Ringtoets.HydraRing.Calculation.Test/Data/Input/Structures/StructuresOvertoppingCalculationInputTest.cs
===================================================================
diff -u -rbd70430bdfc6c901072cf5946c5c096ef4dbcba2 -rf4c5904adf196826278061be33fe3adbc9ad4bc8
--- Ringtoets/HydraRing/test/Ringtoets.HydraRing.Calculation.Test/Data/Input/Structures/StructuresOvertoppingCalculationInputTest.cs (.../StructuresOvertoppingCalculationInputTest.cs) (revision bd70430bdfc6c901072cf5946c5c096ef4dbcba2)
+++ Ringtoets/HydraRing/test/Ringtoets.HydraRing.Calculation.Test/Data/Input/Structures/StructuresOvertoppingCalculationInputTest.cs (.../StructuresOvertoppingCalculationInputTest.cs) (revision f4c5904adf196826278061be33fe3adbc9ad4bc8)
@@ -35,8 +35,8 @@
{
// Setup
const int hydraulicBoundaryLocationId = 1000;
- const int variableId = 60;
- HydraRingSection hydraRingSection = new HydraRingSection(variableId, "1000", double.NaN, double.NaN);
+
+ HydraRingSection hydraRingSection = new HydraRingSection(1, "1000", double.NaN, double.NaN);
const double gravitationalAcceleration = 9.81;
const double modelFactorOvertoppingMean = 0.09;
const double modelFactorOvertoppingStandardDeviation = 0.06;
@@ -65,26 +65,26 @@
const double deviationOfTheWaveDirection = 9.9;
// Call
- StructuresOvertoppingCalculationInput structuresOvertoppingCalculationInput =
- new StructuresOvertoppingCalculationInput(hydraulicBoundaryLocationId, hydraRingSection,
- gravitationalAcceleration,
- modelFactorOvertoppingMean, modelFactorOvertoppingStandardDeviation,
- levelOfCrestOfStructureMean, levelOfCrestOfStructureStandardDeviation,
- orientationOfTheNormalOfTheStructure,
- modelFactorOvertoppingSupercriticalFlowMean, modelFactorOvertoppingSupercriticalFlowStandardDeviation,
- allowableIncreaseOfLevelForStorageMean, allowableIncreaseOfLevelForStorageStandardDeviation,
- modelFactorForStorageVolumeMean, modelFactorForStorageVolumeStandardDeviation,
- storageStructureAreaMean, storageStructureAreaStandardDeviation,
- modelFactorForIncomingFlowVolume,
- flowWidthAtBottomProtectionMean, flowWidthAtBottomProtectionStandardDeviation,
- criticalOvertoppingDischargeMean, criticalOvertoppingDischargeMeanStandardDeviation,
- failureProbabilityOfStructureGivenErosion,
- widthOfFlowAperturesMean, widthOfFlowAperturesStandardDeviation,
- deviationOfTheWaveDirection,
- stormDurationMean, stormDurationStandardDeviation);
+ var structuresOvertoppingCalculationInput = new StructuresOvertoppingCalculationInput(hydraulicBoundaryLocationId, hydraRingSection,
+ gravitationalAcceleration,
+ modelFactorOvertoppingMean, modelFactorOvertoppingStandardDeviation,
+ levelOfCrestOfStructureMean, levelOfCrestOfStructureStandardDeviation,
+ orientationOfTheNormalOfTheStructure,
+ modelFactorOvertoppingSupercriticalFlowMean, modelFactorOvertoppingSupercriticalFlowStandardDeviation,
+ allowableIncreaseOfLevelForStorageMean, allowableIncreaseOfLevelForStorageStandardDeviation,
+ modelFactorForStorageVolumeMean, modelFactorForStorageVolumeStandardDeviation,
+ storageStructureAreaMean, storageStructureAreaStandardDeviation,
+ modelFactorForIncomingFlowVolume,
+ flowWidthAtBottomProtectionMean, flowWidthAtBottomProtectionStandardDeviation,
+ criticalOvertoppingDischargeMean, criticalOvertoppingDischargeMeanStandardDeviation,
+ failureProbabilityOfStructureGivenErosion,
+ widthOfFlowAperturesMean, widthOfFlowAperturesStandardDeviation,
+ deviationOfTheWaveDirection,
+ stormDurationMean, stormDurationStandardDeviation);
// Assert
const int expectedCalculationTypeId = 1;
+ const int variableId = 60;
Assert.AreEqual(expectedCalculationTypeId, structuresOvertoppingCalculationInput.CalculationTypeId);
Assert.AreEqual(hydraulicBoundaryLocationId, structuresOvertoppingCalculationInput.HydraulicBoundaryLocationId);
Assert.AreEqual(HydraRingFailureMechanismType.StructuresOvertopping, structuresOvertoppingCalculationInput.FailureMechanismType);
@@ -122,7 +122,7 @@
yield return new HydraRingVariableImplementation(103, HydraRingDistributionType.Normal, double.NaN, HydraRingDeviationType.Standard, 5.5, 0.05, double.NaN);
yield return new HydraRingVariableImplementation(104, HydraRingDistributionType.LogNormal, double.NaN, HydraRingDeviationType.Variation, 6.6, 0.15, double.NaN);
yield return new HydraRingVariableImplementation(105, HydraRingDistributionType.Deterministic, 7.7, HydraRingDeviationType.Standard, double.NaN, double.NaN, double.NaN);
- yield return new HydraRingVariableImplementation(106, HydraRingDistributionType.Normal, double.NaN, HydraRingDeviationType.Standard, 8.8, 0.05, double.NaN);
+ yield return new HydraRingVariableImplementation(106, HydraRingDistributionType.Normal, double.NaN, HydraRingDeviationType.Variation, 8.8, 0.05, double.NaN);
yield return new HydraRingVariableImplementation(107, HydraRingDistributionType.Deterministic, 9.9, HydraRingDeviationType.Variation, double.NaN, double.NaN, double.NaN);
yield return new HydraRingVariableImplementation(108, HydraRingDistributionType.LogNormal, double.NaN, HydraRingDeviationType.Variation, 7.5, 0.25, double.NaN);
}
Index: Ringtoets/HydraRing/test/Ringtoets.HydraRing.Calculation.Test/Integration/HydraRingConfigurationServiceIntegrationTest.cs
===================================================================
diff -u -rbd70430bdfc6c901072cf5946c5c096ef4dbcba2 -rf4c5904adf196826278061be33fe3adbc9ad4bc8
--- Ringtoets/HydraRing/test/Ringtoets.HydraRing.Calculation.Test/Integration/HydraRingConfigurationServiceIntegrationTest.cs (.../HydraRingConfigurationServiceIntegrationTest.cs) (revision bd70430bdfc6c901072cf5946c5c096ef4dbcba2)
+++ Ringtoets/HydraRing/test/Ringtoets.HydraRing.Calculation.Test/Integration/HydraRingConfigurationServiceIntegrationTest.cs (.../HydraRingConfigurationServiceIntegrationTest.cs) (revision f4c5904adf196826278061be33fe3adbc9ad4bc8)
@@ -105,9 +105,9 @@
{
// Setup
var hydraRingConfigurationService = new HydraRingConfigurationService("34-1", HydraRingTimeIntegrationSchemeType.FBC, HydraRingUncertaintiesType.All);
- int hydraulicBoundaryLocationId = 700004;
+ const int hydraulicBoundaryLocationId = 700004;
- var hydraRingSection = new HydraRingSection(hydraulicBoundaryLocationId, "700004", 2.2, 3.3);
+ var hydraRingSection = new HydraRingSection(1, "700004", 2.2, 3.3);
const double dikeHeight = 11.11;
const double modelFactorCriticalOvertopping = 1;
const double factorFnMean = 4.75;
@@ -142,34 +142,34 @@
"INSERT INTO [HydraulicModels] VALUES (1, 1, 'WTI 2017');" + Environment.NewLine +
Environment.NewLine +
"DELETE FROM [Sections];" + Environment.NewLine +
- "INSERT INTO [Sections] VALUES (700004, 1, 1, '700004', '700004', 0, 0, 0, 0, 700004, 700004, 100, 3.3, 2.2);" + Environment.NewLine +
+ "INSERT INTO [Sections] VALUES (1, 1, 1, '700004', '700004', 0, 0, 0, 0, 700004, 700004, 100, 3.3, 2.2);" + Environment.NewLine +
Environment.NewLine +
"DELETE FROM [DesignTables];" + Environment.NewLine +
- "INSERT INTO [DesignTables] VALUES (700004, 101, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0);" + Environment.NewLine +
+ "INSERT INTO [DesignTables] VALUES (1, 101, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0);" + Environment.NewLine +
Environment.NewLine +
"DELETE FROM [Numerics];" + Environment.NewLine +
- "INSERT INTO [Numerics] VALUES (700004, 101, 1, 1, 102, 1, 4, 50, 0.15, 0.01, 0.01, 0.01, 2, 1, 20000, 100000, 0.1, -6, 6, 25);" + Environment.NewLine +
- "INSERT INTO [Numerics] VALUES (700004, 101, 1, 1, 103, 1, 4, 50, 0.15, 0.01, 0.01, 0.01, 2, 1, 20000, 100000, 0.1, -6, 6, 25);" + Environment.NewLine +
+ "INSERT INTO [Numerics] VALUES (1, 101, 1, 1, 102, 1, 4, 50, 0.15, 0.01, 0.01, 0.01, 2, 1, 20000, 100000, 0.1, -6, 6, 25);" + Environment.NewLine +
+ "INSERT INTO [Numerics] VALUES (1, 101, 1, 1, 103, 1, 4, 50, 0.15, 0.01, 0.01, 0.01, 2, 1, 20000, 100000, 0.1, -6, 6, 25);" + Environment.NewLine +
Environment.NewLine +
"DELETE FROM [VariableDatas];" + Environment.NewLine +
- "INSERT INTO [VariableDatas] VALUES (700004, 101, 1, 1, 1, 11.11, 0, 0, NULL, NULL, NULL, 0, 0, 300);" + Environment.NewLine +
- "INSERT INTO [VariableDatas] VALUES (700004, 101, 1, 1, 8, 1, 0, 0, NULL, NULL, NULL, 0, 0, 300);" + Environment.NewLine +
- "INSERT INTO [VariableDatas] VALUES (700004, 101, 1, 1, 10, 0, 2, 4.75, 0.5, NULL, NULL, 0, 0, 300);" + Environment.NewLine +
- "INSERT INTO [VariableDatas] VALUES (700004, 101, 1, 1, 11, 0, 2, 2.6, 0.35, NULL, NULL, 0, 0, 300);" + Environment.NewLine +
- "INSERT INTO [VariableDatas] VALUES (700004, 101, 1, 1, 12, 1, 0, 0, NULL, NULL, NULL, 0, 0, 300);" + Environment.NewLine +
- "INSERT INTO [VariableDatas] VALUES (700004, 101, 1, 1, 17, 0, 4, 22.22, 33.33, NULL, NULL, 0, 0, 300);" + Environment.NewLine +
- "INSERT INTO [VariableDatas] VALUES (700004, 101, 1, 1, 120, 0, 2, 1, NULL, NULL, NULL, 1, 0.07, 300);" + Environment.NewLine +
- "INSERT INTO [VariableDatas] VALUES (700004, 101, 1, 1, 123, 0, 2, 0.92, 0.24, NULL, NULL, 0, 0, 300);" + Environment.NewLine +
+ "INSERT INTO [VariableDatas] VALUES (1, 101, 1, 1, 1, 11.11, 0, 0, NULL, NULL, NULL, 0, 0, 300);" + Environment.NewLine +
+ "INSERT INTO [VariableDatas] VALUES (1, 101, 1, 1, 8, 1, 0, 0, NULL, NULL, NULL, 0, 0, 300);" + Environment.NewLine +
+ "INSERT INTO [VariableDatas] VALUES (1, 101, 1, 1, 10, 0, 2, 4.75, 0.5, NULL, NULL, 0, 0, 300);" + Environment.NewLine +
+ "INSERT INTO [VariableDatas] VALUES (1, 101, 1, 1, 11, 0, 2, 2.6, 0.35, NULL, NULL, 0, 0, 300);" + Environment.NewLine +
+ "INSERT INTO [VariableDatas] VALUES (1, 101, 1, 1, 12, 1, 0, 0, NULL, NULL, NULL, 0, 0, 300);" + Environment.NewLine +
+ "INSERT INTO [VariableDatas] VALUES (1, 101, 1, 1, 17, 0, 4, 22.22, 33.33, NULL, NULL, 0, 0, 300);" + Environment.NewLine +
+ "INSERT INTO [VariableDatas] VALUES (1, 101, 1, 1, 120, 0, 2, 1, NULL, NULL, NULL, 1, 0.07, 300);" + Environment.NewLine +
+ "INSERT INTO [VariableDatas] VALUES (1, 101, 1, 1, 123, 0, 2, 0.92, 0.24, NULL, NULL, 0, 0, 300);" + Environment.NewLine +
Environment.NewLine +
"DELETE FROM [CalculationProfiles];" + Environment.NewLine +
- "INSERT INTO [CalculationProfiles] VALUES (700004, 1, 1.1, 2.2, 3.3);" + Environment.NewLine +
+ "INSERT INTO [CalculationProfiles] VALUES (1, 1, 1.1, 2.2, 3.3);" + Environment.NewLine +
Environment.NewLine +
"DELETE FROM [SectionFaultTreeModels];" + Environment.NewLine +
- "INSERT INTO [SectionFaultTreeModels] VALUES (700004, 101, 1, 1, 1017);" + Environment.NewLine +
+ "INSERT INTO [SectionFaultTreeModels] VALUES (1, 101, 1, 1, 1017);" + Environment.NewLine +
Environment.NewLine +
"DELETE FROM [SectionSubMechanismModels];" + Environment.NewLine +
- "INSERT INTO [SectionSubMechanismModels] VALUES (700004, 1, 1, 102, 94);" + Environment.NewLine +
- "INSERT INTO [SectionSubMechanismModels] VALUES (700004, 1, 1, 103, 95);" + Environment.NewLine +
+ "INSERT INTO [SectionSubMechanismModels] VALUES (1, 1, 1, 102, 94);" + Environment.NewLine +
+ "INSERT INTO [SectionSubMechanismModels] VALUES (1, 1, 1, 103, 95);" + Environment.NewLine +
Environment.NewLine +
"DELETE FROM [Fetches];" + Environment.NewLine +
Environment.NewLine +
@@ -178,12 +178,12 @@
"DELETE FROM [PresentationSections];" + Environment.NewLine +
Environment.NewLine +
"DELETE FROM [Profiles];" + Environment.NewLine +
- "INSERT INTO [Profiles] VALUES (700004, 1, 1.1, 2.2);" + Environment.NewLine +
+ "INSERT INTO [Profiles] VALUES (1, 1, 1.1, 2.2);" + Environment.NewLine +
Environment.NewLine +
"DELETE FROM [ForelandModels];" + Environment.NewLine +
Environment.NewLine +
"DELETE FROM [Forelands];" + Environment.NewLine +
- "INSERT INTO [Forelands] VALUES (700004, 1, 1.1, 2.2);" + Environment.NewLine +
+ "INSERT INTO [Forelands] VALUES (1, 1, 1.1, 2.2);" + Environment.NewLine +
Environment.NewLine +
"DELETE FROM [ProbabilityAlternatives];" + Environment.NewLine +
Environment.NewLine +
@@ -202,7 +202,7 @@
"INSERT INTO [Projects] VALUES (1, 'WTI 2017', 'Ringtoets calculation');" + Environment.NewLine +
Environment.NewLine +
"DELETE FROM [Breakwaters];" + Environment.NewLine +
- "INSERT INTO [Breakwaters] VALUES (700004, 1, 2.2);" + Environment.NewLine;
+ "INSERT INTO [Breakwaters] VALUES (1, 1, 2.2);" + Environment.NewLine;
// Call
var creationScript = hydraRingConfigurationService.GenerateDataBaseCreationScript();
@@ -216,9 +216,9 @@
{
// Setup
var hydraRingConfigurationService = new HydraRingConfigurationService("34-1", HydraRingTimeIntegrationSchemeType.FBC, HydraRingUncertaintiesType.All);
- int hydraulicBoundaryLocationId = 700004;
+ const int hydraulicBoundaryLocationId = 700004;
- var hydraRingSection = new HydraRingSection(hydraulicBoundaryLocationId, "700004", 2.2, 3.3);
+ var hydraRingSection = new HydraRingSection(1, "700004", 2.2, 3.3);
const double gravitationalAcceleration = 9.81;
const double modelFactorOvertoppingMean = 0.09;
const double modelFactorOvertoppingStandardDeviation = 0.06;
@@ -271,37 +271,37 @@
"INSERT INTO [HydraulicModels] VALUES (1, 1, 'WTI 2017');" + Environment.NewLine +
Environment.NewLine +
"DELETE FROM [Sections];" + Environment.NewLine +
- "INSERT INTO [Sections] VALUES (700004, 1, 1, '700004', '700004', 0, 0, 0, 0, 700004, 700004, 100, 3.3, 2.2);" + Environment.NewLine +
+ "INSERT INTO [Sections] VALUES (1, 1, 1, '700004', '700004', 0, 0, 0, 0, 700004, 700004, 100, 3.3, 2.2);" + Environment.NewLine +
Environment.NewLine +
"DELETE FROM [DesignTables];" + Environment.NewLine +
- "INSERT INTO [DesignTables] VALUES (700004, 110, 1, 1, 1, 60, 0, 0, 0, 0, 0, 0, 0);" + Environment.NewLine +
+ "INSERT INTO [DesignTables] VALUES (1, 110, 1, 1, 1, 60, 0, 0, 0, 0, 0, 0, 0);" + Environment.NewLine +
Environment.NewLine +
"DELETE FROM [Numerics];" + Environment.NewLine +
- "INSERT INTO [Numerics] VALUES (700004, 110, 1, 1, 421, 1, 4, 50, 0.15, 0.01, 0.01, 0.01, 2, 1, 10000, 20000, 0.1, -6, 6, 25);" + Environment.NewLine +
- "INSERT INTO [Numerics] VALUES (700004, 110, 1, 1, 422, 1, 4, 50, 0.15, 0.01, 0.01, 0.01, 2, 1, 10000, 20000, 0.1, -6, 6, 25);" + Environment.NewLine +
- "INSERT INTO [Numerics] VALUES (700004, 110, 1, 1, 423, 1, 4, 50, 0.15, 0.01, 0.01, 0.01, 2, 1, 10000, 20000, 0.1, -6, 6, 25);" + Environment.NewLine +
+ "INSERT INTO [Numerics] VALUES (1, 110, 1, 1, 421, 1, 4, 50, 0.15, 0.01, 0.01, 0.01, 2, 1, 10000, 20000, 0.1, -6, 6, 25);" + Environment.NewLine +
+ "INSERT INTO [Numerics] VALUES (1, 110, 1, 1, 422, 1, 4, 50, 0.15, 0.01, 0.01, 0.01, 2, 1, 10000, 20000, 0.1, -6, 6, 25);" + Environment.NewLine +
+ "INSERT INTO [Numerics] VALUES (1, 110, 1, 1, 423, 1, 4, 50, 0.15, 0.01, 0.01, 0.01, 2, 1, 10000, 20000, 0.1, -6, 6, 25);" + Environment.NewLine +
Environment.NewLine +
"DELETE FROM [VariableDatas];" + Environment.NewLine +
- "INSERT INTO [VariableDatas] VALUES (700004, 110, 1, 1, 58, 9.81, 0, 0, NULL, NULL, NULL, 1, 0, 99000);" + Environment.NewLine +
- "INSERT INTO [VariableDatas] VALUES (700004, 110, 1, 1, 59, 0, 4, 0.09, 0.06, NULL, NULL, 0, 0, 999999);" + Environment.NewLine +
- "INSERT INTO [VariableDatas] VALUES (700004, 110, 1, 1, 60, 0, 2, 1.1, 0.05, NULL, NULL, 0, 0, 999999);" + Environment.NewLine +
- "INSERT INTO [VariableDatas] VALUES (700004, 110, 1, 1, 61, 2.2, 0, 0, NULL, NULL, NULL, 1, 0, 999999);" + Environment.NewLine +
- "INSERT INTO [VariableDatas] VALUES (700004, 110, 1, 1, 62, 0, 2, 1.1, 0.03, NULL, NULL, 0, 0, 999999);" + Environment.NewLine +
- "INSERT INTO [VariableDatas] VALUES (700004, 110, 1, 1, 94, 0, 4, 3.3, 0.1, NULL, NULL, 0, 0, 999999);" + Environment.NewLine +
- "INSERT INTO [VariableDatas] VALUES (700004, 110, 1, 1, 95, 0, 4, 1, 0.2, NULL, NULL, 0, 0, 999999);" + Environment.NewLine +
- "INSERT INTO [VariableDatas] VALUES (700004, 110, 1, 1, 96, 0, 4, 4.4, NULL, NULL, NULL, 1, 0.1, 999999);" + Environment.NewLine +
- "INSERT INTO [VariableDatas] VALUES (700004, 110, 1, 1, 97, 1, 0, 0, NULL, NULL, NULL, 0, 0, 999999);" + Environment.NewLine +
- "INSERT INTO [VariableDatas] VALUES (700004, 110, 1, 1, 103, 0, 2, 5.5, 0.05, NULL, NULL, 0, 0, 999999);" + Environment.NewLine +
- "INSERT INTO [VariableDatas] VALUES (700004, 110, 1, 1, 104, 0, 4, 6.6, NULL, NULL, NULL, 1, 0.15, 999999);" + Environment.NewLine +
- "INSERT INTO [VariableDatas] VALUES (700004, 110, 1, 1, 105, 7.7, 0, 0, NULL, NULL, NULL, 0, 0, 999999);" + Environment.NewLine +
- "INSERT INTO [VariableDatas] VALUES (700004, 110, 1, 1, 106, 0, 2, 8.8, 0.05, NULL, NULL, 0, 0, 999999);" + Environment.NewLine +
- "INSERT INTO [VariableDatas] VALUES (700004, 110, 1, 1, 107, 9.9, 0, 0, NULL, NULL, NULL, 1, 0, 99000);" + Environment.NewLine +
- "INSERT INTO [VariableDatas] VALUES (700004, 110, 1, 1, 108, 0, 4, 7.5, NULL, NULL, NULL, 1, 0.25, 999999);" + Environment.NewLine +
+ "INSERT INTO [VariableDatas] VALUES (1, 110, 1, 1, 58, 9.81, 0, 0, NULL, NULL, NULL, 1, 0, 99000);" + Environment.NewLine +
+ "INSERT INTO [VariableDatas] VALUES (1, 110, 1, 1, 59, 0, 4, 0.09, 0.06, NULL, NULL, 0, 0, 999999);" + Environment.NewLine +
+ "INSERT INTO [VariableDatas] VALUES (1, 110, 1, 1, 60, 0, 2, 1.1, 0.05, NULL, NULL, 0, 0, 999999);" + Environment.NewLine +
+ "INSERT INTO [VariableDatas] VALUES (1, 110, 1, 1, 61, 2.2, 0, 0, NULL, NULL, NULL, 1, 0, 999999);" + Environment.NewLine +
+ "INSERT INTO [VariableDatas] VALUES (1, 110, 1, 1, 62, 0, 2, 1.1, 0.03, NULL, NULL, 0, 0, 999999);" + Environment.NewLine +
+ "INSERT INTO [VariableDatas] VALUES (1, 110, 1, 1, 94, 0, 4, 3.3, 0.1, NULL, NULL, 0, 0, 999999);" + Environment.NewLine +
+ "INSERT INTO [VariableDatas] VALUES (1, 110, 1, 1, 95, 0, 4, 1, 0.2, NULL, NULL, 0, 0, 999999);" + Environment.NewLine +
+ "INSERT INTO [VariableDatas] VALUES (1, 110, 1, 1, 96, 0, 4, 4.4, NULL, NULL, NULL, 1, 0.1, 999999);" + Environment.NewLine +
+ "INSERT INTO [VariableDatas] VALUES (1, 110, 1, 1, 97, 1, 0, 0, NULL, NULL, NULL, 0, 0, 999999);" + Environment.NewLine +
+ "INSERT INTO [VariableDatas] VALUES (1, 110, 1, 1, 103, 0, 2, 5.5, 0.05, NULL, NULL, 0, 0, 999999);" + Environment.NewLine +
+ "INSERT INTO [VariableDatas] VALUES (1, 110, 1, 1, 104, 0, 4, 6.6, NULL, NULL, NULL, 1, 0.15, 999999);" + Environment.NewLine +
+ "INSERT INTO [VariableDatas] VALUES (1, 110, 1, 1, 105, 7.7, 0, 0, NULL, NULL, NULL, 0, 0, 999999);" + Environment.NewLine +
+ "INSERT INTO [VariableDatas] VALUES (1, 110, 1, 1, 106, 0, 2, 8.8, NULL, NULL, NULL, 1, 0.05, 999999);" + Environment.NewLine +
+ "INSERT INTO [VariableDatas] VALUES (1, 110, 1, 1, 107, 9.9, 0, 0, NULL, NULL, NULL, 1, 0, 99000);" + Environment.NewLine +
+ "INSERT INTO [VariableDatas] VALUES (1, 110, 1, 1, 108, 0, 4, 7.5, NULL, NULL, NULL, 1, 0.25, 999999);" + Environment.NewLine +
Environment.NewLine +
"DELETE FROM [CalculationProfiles];" + Environment.NewLine +
Environment.NewLine +
"DELETE FROM [SectionFaultTreeModels];" + Environment.NewLine +
- "INSERT INTO [SectionFaultTreeModels] VALUES (700004, 110, 1, 1, 4404);" + Environment.NewLine +
+ "INSERT INTO [SectionFaultTreeModels] VALUES (1, 110, 1, 1, 4404);" + Environment.NewLine +
Environment.NewLine +
"DELETE FROM [SectionSubMechanismModels];" + Environment.NewLine +
Environment.NewLine +
Index: Ringtoets/HydraRing/src/Ringtoets.HydraRing.Calculation/Data/Input/Structures/StructuresOvertoppingCalculationInput.cs
===================================================================
diff -u -rbd70430bdfc6c901072cf5946c5c096ef4dbcba2 -rf4c5904adf196826278061be33fe3adbc9ad4bc8
--- Ringtoets/HydraRing/src/Ringtoets.HydraRing.Calculation/Data/Input/Structures/StructuresOvertoppingCalculationInput.cs (.../StructuresOvertoppingCalculationInput.cs) (revision bd70430bdfc6c901072cf5946c5c096ef4dbcba2)
+++ Ringtoets/HydraRing/src/Ringtoets.HydraRing.Calculation/Data/Input/Structures/StructuresOvertoppingCalculationInput.cs (.../StructuresOvertoppingCalculationInput.cs) (revision f4c5904adf196826278061be33fe3adbc9ad4bc8)
@@ -50,7 +50,7 @@
private readonly double criticalOvertoppingDischargeVariation;
private readonly double failureProbabilityOfStructureGivenErosion;
private readonly double widthOfFlowAperturesMean;
- private readonly double widthOfFlowAperturesStandardDeviation;
+ private readonly double widthOfFlowAperturesVariation;
private readonly double deviationOfTheWaveDirection;
private readonly double stormDurationMean;
private readonly double stormDurationVariation;
@@ -81,7 +81,7 @@
/// The variation of the critical overtopping discharge to use during the calculation.
/// The failure probability of structure given erosion to use during the calculation.
/// The mean of the width of flow apertures to use during the calculation.
/// The standard deviation of the width of flow apertures to use during the calculation.
/// The deviation of the wave direction to use during the calculation.
/// The mean of the storm duration to use during the calculation.
/// The variation of the storm duration to use during the calculation.
@@ -98,7 +98,7 @@
double hydraRingFlowWidthAtBottomProtectionMean, double hydraRingFlowWidthAtBottomProtectionStandardDeviation,
double hydraRingCriticalOvertoppingDischargeMean, double hydraRingCriticalOvertoppingDischargeVariation,
double hydraRingFailureProbabilityOfStructureGivenErosion,
- double hydraRingWidthOfFlowAperturesMean, double hydraRingWidthOfFlowAperturesStandardDeviation,
+ double hydraRingWidthOfFlowAperturesMean, double hydraRingWidthOfFlowAperturesVariation,
double hydraRingDeviationOfTheWaveDirection,
double hydraRingStormDurationMean, double hydraRingStormDurationVariation
)
@@ -126,7 +126,7 @@
criticalOvertoppingDischargeVariation = hydraRingCriticalOvertoppingDischargeVariation;
failureProbabilityOfStructureGivenErosion = hydraRingFailureProbabilityOfStructureGivenErosion;
widthOfFlowAperturesMean = hydraRingWidthOfFlowAperturesMean;
- widthOfFlowAperturesStandardDeviation = hydraRingWidthOfFlowAperturesStandardDeviation;
+ widthOfFlowAperturesVariation = hydraRingWidthOfFlowAperturesVariation;
deviationOfTheWaveDirection = hydraRingDeviationOfTheWaveDirection;
stormDurationMean = hydraRingStormDurationMean;
stormDurationVariation = hydraRingStormDurationVariation;
@@ -172,7 +172,7 @@
yield return new OvertoppingFlowWidthAtBottomProtection(flowWidthAtBottomProtectionMean, flowWidthAtBottomProtectionStandardDeviation);
yield return new OvertoppingCriticalOvertoppingDischarge(criticalOvertoppingDischargeMean, criticalOvertoppingDischargeVariation);
yield return new OvertoppingFailureProbabilityOfStructureGivenErosion(failureProbabilityOfStructureGivenErosion);
- yield return new OvertoppingWidthOfFlowApertures(widthOfFlowAperturesMean, widthOfFlowAperturesStandardDeviation);
+ yield return new OvertoppingWidthOfFlowApertures(widthOfFlowAperturesMean, widthOfFlowAperturesVariation);
yield return new OvertoppingDeviationOfTheWaveDirection(deviationOfTheWaveDirection);
yield return new OvertoppingStormDuration(stormDurationMean, stormDurationVariation);
}
@@ -255,7 +255,7 @@
private class OvertoppingWidthOfFlowApertures : HydraRingVariable
{
public OvertoppingWidthOfFlowApertures(double mean, double standardDeviation) :
- base(106, HydraRingDistributionType.Normal, double.NaN, HydraRingDeviationType.Standard, mean, standardDeviation, double.NaN) {}
+ base(106, HydraRingDistributionType.Normal, double.NaN, HydraRingDeviationType.Variation, mean, standardDeviation, double.NaN) {}
}
private class OvertoppingDeviationOfTheWaveDirection : HydraRingVariable
@@ -81,7 +81,7 @@
/// The failure probability of structure given erosion to use during the calculation.
/// The mean of the width of flow apertures to use during the calculation.
- /// The standard deviation of the width of flow apertures to use during the calculation.
+ /// The variation of the width of flow apertures to use during the calculation.
/// The deviation of the wave direction to use during the calculation.
/// The mean of the storm duration to use during the calculation.